CHANGES
=======

01/20/2025

1.0.0

First public release. Add trepan3k debugger command functions

* ``mathics3``: Go into a Mathic3 shell
* ``mbacktrace``: backtrace showing interesting Mathics3 frame interpretation
* ``mup``: frame up allowing for jumping to interesting Mathics3 frame
* ``mdown``, frame down allowing for jumping to interesting Mathics3 frame
* ``printelement``: print customized for Mathics3 objects
